@@ -4,6 +4,7 @@ from django.core.validators import validate_email
 
 from floraconcierge.apiauth.models import User
 from floraconcierge.errors import ResultDefaultError
+from floraconcierge.shortcuts import get_apiclient
 from floraconcierge.shortcuts.users import login, get_logged_user
 
 
@@ -24,6 +25,9 @@ class FloraConciergeBackend(ModelBackend):
 
     def get_user(self, user_id):
         try:
+            if not get_apiclient().env.user_auth_key:
+                return None
+
             user = get_logged_user()
             if user:
                 return User.from_api_user(user)
